V1.0.0(BETA)
Activate Win10
Relies on easygui
V1.0.1(BETA)
Increase dependent on requests
Added confirmation of network connectivity, as well as KMS server connectivity test
Fixed some hints for activating the wizard